@@ -211,8 +211,8 @@ class World:
                 "required": True,
             },
         )
-        pose: "World.Include.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["World.Include.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -230,7 +230,7 @@ class World:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -320,8 +320,8 @@ class World:
                     "namespace": "",
                 },
             )
-            pose: "World.Gui.Camera.Pose" = field(
-                default="0 0 0 0 0 0",
+            pose: Optional["World.Gui.Camera.Pose"] = field(
+                default=None,
                 metadata={
                     "type": "Element",
                     "namespace": "",
@@ -377,8 +377,8 @@ class World:
                     frame is attached to.
                 """
 
-                pose: "World.Gui.Camera.Frame.Pose" = field(
-                    default="0 0 0 0 0 0",
+                pose: Optional["World.Gui.Camera.Frame.Pose"] = field(
+                    default=None,
                     metadata={
                         "type": "Element",
                         "namespace": "",
@@ -404,7 +404,7 @@ class World:
                     """
 
                     value: str = field(
-                        default="",
+                        default="0 0 0 0 0 0",
                         metadata={
                             "required": True,
                             "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -428,7 +428,7 @@ class World:
                 """
 
                 value: str = field(
-                    default="",
+                    default="0 0 0 0 0 0",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -686,8 +686,8 @@ class World:
                 "namespace": "",
             },
         )
-        pose: "World.Population.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["World.Population.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -832,8 +832,8 @@ class World:
                 attached to.
             """
 
-            pose: "World.Population.Frame.Pose" = field(
-                default="0 0 0 0 0 0",
+            pose: Optional["World.Population.Frame.Pose"] = field(
+                default=None,
                 metadata={
                     "type": "Element",
                     "namespace": "",
@@ -859,7 +859,7 @@ class World:
                 """
 
                 value: str = field(
-                    default="",
+                    default="0 0 0 0 0 0",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -882,7 +882,7 @@ class World:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
